==> genshin-1.6.0-py3-none-any.whl: genshin/models/honkai/constants.py <==
"""Honkai model constants."""
import typing

__all__ = ["BATTLESUIT_IDENTIFIERS"]

# TODO: Make this more dynamic
# fmt: off
BATTLESUIT_IDENTIFIERS: typing.Dict[int, str] = {
    101: "KianaC2",
    102: "KianaC1",
    103: "KianaC4",
    104: "KianaC3",
    105: "KianaC6",
    106: "KianaC7",

    111: "KallenC1",
    112: "KallenC2",
    113: "KianaC5",
    114: "KallenC3",

    201: "MeiC2",
    202: "MeiC3",
    203: "MeiC1",
    204: "MeiC4",
    205: "MeiC5",
    206: "MeiC6",

    211: "SakuraC1",
    212: "SakuraC2",
    213: "SakuraC3",
    214: "SakuraC4",

    301: "BronyaC1",
    302: "BronyaC2",
    303: "BronyaC3",
    304: "BronyaC4",
    311: "BronyaC5",
    312: "BronyaC6",
    313: "BronyaC7",
    314: "BronyaC8",
    315: "BronyaC10",
    317: "BronyaC12",

    401: "HimekoC1",
    402: "HimekoC2",
    403: "HimekoC3",
    404: "HimekoC4",
    411: "HimekoC5",
    412: "HimekoC6",

    421: "TwinC1",
    422: "TwinC2",

    501: "TheresaC1",
    502: "TheresaC2",
    503: "TheresaC3",
    504: "TheresaC4",
    506: "TheresaC6",
    511: "TheresaC5",

    601: "FukaC1",
    602: "FukaC2",
    603: "FukaC3",
    604: "FukaC4",
    611: "FukaC5",
    612: "FukaC6",

    702: "RitaC2",
    703: "RitaC3",
    704: "RitaC4",
    705: "RitaC5",
    706: "RitaC6",

    711: "SeeleC1",
    712: "SeeleC2",
    713: "SeeleC3",

    801: "DurandalC1",
    802: "DurandalC2",
    803: "DurandalC3",
    804: "DurandalC4",

    901: "AsukaC1",

    2101: "FischlC1",

    2201: "ElysiaC1",
    2202: "ElysiaC2",

    2301: "MobiusC1",
    2401: "RavenC1",
    2501: "CaroleC1",
    2601: "PardofelisC1",
    2701: "AponiaC1",
    2801: "EdenC1",
    2901: "GriseoC1",
    3001: "Vill_VC1",
    3101: "LisushangC2",
    3201: "AIC1",
}
# fmt: on

==> genshin-1.7.18-py3-none-any.whl: genshin/models/honkai/constants.py <==
"""Honkai model constants."""

__all__ = ["BATTLESUIT_IDENTIFIERS"]

# TODO: Make this more dynamic
# fmt: off
BATTLESUIT_IDENTIFIERS: dict[int, str] = {
    101: "KianaC2",
    102: "KianaC1",
    103: "KianaC4",
    104: "KianaC3",
    105: "KianaC6",
    106: "KianaC7",

    111: "KallenC1",
    112: "KallenC2",
    113: "KianaC5",
    114: "KallenC3",

    201: "MeiC2",
    202: "MeiC3",
    203: "MeiC1",
    204: "MeiC4",
    205: "MeiC5",
    206: "MeiC6",

    211: "SakuraC1",
    212: "SakuraC2",
    213: "SakuraC3",
    214: "SakuraC4",

    301: "BronyaC1",
    302: "BronyaC2",
    303: "BronyaC3",
    304: "BronyaC4",
    311: "BronyaC5",
    312: "BronyaC6",
    313: "BronyaC7",
    314: "BronyaC8",
    315: "BronyaC10",
    317: "BronyaC12",

    401: "HimekoC1",
    402: "HimekoC2",
    403: "HimekoC3",
    404: "HimekoC4",
    411: "HimekoC5",
    412: "HimekoC6",

    421: "TwinC1",
    422: "TwinC2",

    501: "TheresaC1",
    502: "TheresaC2",
    503: "TheresaC3",
    504: "TheresaC4",
    506: "TheresaC6",
    511: "TheresaC5",

    601: "FukaC1",
    602: "FukaC2",
    603: "FukaC3",
    604: "FukaC4",
    611: "FukaC5",
    612: "FukaC6",

    702: "RitaC2",
    703: "RitaC3",
    704: "RitaC4",
    705: "RitaC5",
    706: "RitaC6",

    711: "SeeleC1",
    712: "SeeleC2",
    713: "SeeleC3",

    801: "DurandalC1",
    802: "DurandalC2",
    803: "DurandalC3",
    804: "DurandalC4",

    901: "AsukaC1",

    2101: "FischlC1",

    2201: "ElysiaC1",
    2202: "ElysiaC2",

    2301: "MobiusC1",
    2401: "RavenC1",
    2501: "CaroleC1",
    2601: "PardofelisC1",
    2701: "AponiaC1",
    2801: "EdenC1",
    2901: "GriseoC1",
    3001: "Vill_VC1",
    3101: "LisushangC2",
    3201: "AIC1",
}
# fmt: on
